library(shiny)

# Define server logic required to draw a histogram
shinyServer(function(input, output) {
   
  output$distPlot <- renderPlot({
    
    # generate bins based on input$bins from ui.R
    x    <- faithful[, input$var] 
    bins <- seq(min(x), max(x), length.out = input$bins + 1)
    
    # draw the histogram with the specified number of bins
    hist(x, breaks = bins, col = input$color, border = 'white', main = input$titre)
    
  })
  
  # summary
  output$summary <- renderPrint({
    summary(faithful)
  })
  
  # table
  output$table <- renderDataTable({
    faithful
  })
  
  # nombre de classe
  output$n_bins <- renderText({
    paste("Number of bins: ", input$bins)
  })
  
  # Download
  output$download_plot <- downloadHandler(
    filename = function() {
      paste('plot-', Sys.Date(), '.jpeg', sep='')
    },
    content = function(con) {
      jpeg(file = con)
      x    <- faithful[, input$var] 
      bins <- seq(min(x), max(x), length.out = input$bins + 1)
      # draw the histogram with the specified number of bins
      hist(x, breaks = bins, col = input$color, border = 'white', main = input$titre)
      dev.off()
    }
  )
})
